import {
  select,
  selectAll,
  scaleLinear,
  axisBottom,
  axisLeft,
  range,
  max,
  schemeSet3,
  easeElasticOut,
} from 'd3';

const w = 600;
const h = 250;
const padding = 40;

let dataset = [];
const numDataPoints = 200;
const xRange = 1000;
const yRange = 1000;

for (let i = 0; i < numDataPoints; i++) {
  let newNumber1 = Math.floor(Math.random() * xRange);
  let newNumber2 = Math.floor(Math.random() * yRange);
  dataset.push([newNumber1, newNumber2]);
}

const xScale = scaleLinear()
  .domain([0, xRange])
  .range([padding, w - padding / 2]);

const yScale = scaleLinear()
  .domain([0, yRange])
  .range([h - padding, padding / 2]);

const xAxis = axisBottom().scale(xScale).ticks(5);

const yAxis = axisLeft().scale(yScale).ticks(5);

const svg = select('body')
  .append('svg')
  .attr('width', w)
  .attr('height', h);

const allCircles = svg
  .selectAll('circle')
  .data(dataset)
  .join('circle')
  .attr('cx', (d) => xScale(d[0]))
  .attr('cy', (d) => yScale(d[1]))
  .attr('r', 3);

svg
  .append('g')
  .attr('class', 'axis')
  .attr('transform', `translate(0, ${h - padding})`)
  .call(xAxis);

svg
  .append('g')
  .attr('class', 'axis')
  .attr('transform', `translate(${padding}, 0)`)
  .call(yAxis);

let currentState = 'freakOut';

selectAll('input').on('click', function () {
  if (currentState == 'freakOut') {
    allCircles.each(freakOut);
    currentState = "normal";
  } else {
  	allCircles.each(restoreNormal);
    currentState = "freakOut";
  }
});

const freakOut = function (d, i) {
  const colors = schemeSet3;
  const colorIndex = Math.floor(Math.random() * 12);

  select(this)
    .transition()
    .delay(i * 10)
    .duration(1000)
    .ease(easeElasticOut)
    .attr('fill', colors[colorIndex])
    .attr('r', 25);
};

const restoreNormal = function (d, i) {

  select(this)
    .transition()
    .delay(i * 10)
    .duration(1000)
    .ease(easeElasticOut)
    .attr('fill', 'black')
    .attr('r', 3);
};
